@@ -1,7 +1,11 @@
 mod client;
 mod user;
+mod error;
 
 pub use oauth2::{TokenResponse, CsrfToken};
 
 pub use user::PhabricatorUser;
-pub use client::PhabOAuthClient;
\ No newline at end of file
+pub use client::PhabOAuthClient;
+pub use error::PhabOAuthError;
+
+pub use reqwest;
